package com.agiledeveloper;

import junit.framework.TestCase;
import static org.easymock.EasyMock.*;

import java.io.FileNotFoundException;

public class MonitorEasyTest extends TestCase
{
    private static final String PATH = "c:\temp";
    private static final String INVALID_PATH = "INVALID_PATH";

    public void testMonitorFileChange()
    {
        Alarm alarm = createMock(Alarm.class);
        alarm.raise();
        replay(alarm);

        FileSystemChange fileSystemChange = createMock(FileSystemChange.class);
        try
        {
            fileSystemChange.lookForChange(PATH);
        }
        catch (FileNotFoundException e)
        {
            fail("Unexepcted exception");
        }
        expect(fileSystemChange.hasChanged()).andReturn(false);
        expect(fileSystemChange.hasChanged()).andReturn(true);
        replay(fileSystemChange);

        FileMonitor m = new FileMonitor(fileSystemChange, alarm);

        m.startMonitoringFile(PATH);
        m.raiseAlarmOnChange();


        m.raiseAlarmOnChange();

        verify(alarm);
        verify(fileSystemChange);
    }

    public void testMonitorInvalidPath()
    {
        // We copied it here from above. We will refactor later.

        Alarm alarm = createMock(Alarm.class);
        alarm.raise();
        replay(alarm);

        FileSystemChange fileSystemChange = createMock(FileSystemChange.class);
        try
        {
            fileSystemChange.lookForChange(INVALID_PATH);
        }
        catch (FileNotFoundException e)
        {
            fail("Unexpected exception");
        }
        expectLastCall().andThrow(new FileNotFoundException());

        replay(fileSystemChange);

        FileMonitor m = new FileMonitor(fileSystemChange, alarm);
        try
        {
            m.startMonitoringFile(INVALID_PATH);
            fail("Expected MonitorException for invalid path");
        }
        catch(MonitorException ex)
        {
            // :) Success
        }
    }

}
